#
# spec file for package xdg-desktop-portal-hyprland
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global __builder ninja

Name:           xdg-desktop-portal-hyprland
Version:        1.3.3
Release:        1.1
Summary:        Extended xdg-desktop-portal backend for Hyprland
License:        MIT
Group:          System/Libraries
URL:            https://github.com/hyprwm/xdg-desktop-portal-hyprland
Source0:        https://github.com/hyprwm/xdg-desktop-portal-hyprland/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  cmake
# Seems some of the C and CXX flags are CLANG specific
BuildRequires:  clang
BuildRequires:  clang-devel
BuildRequires:  hyprland-protocols-devel
BuildRequires:  ninja
BuildRequires:  pipewire-devel
BuildRequires:  pkgconfig
BuildRequires:  qt6-base-devel
BuildRequires:  qt6-wayland
BuildRequires:  qt6-wayland-devel
BuildRequires:  qt6-waylandclient-devel
BuildRequires:  qt6-waylandclient-private-devel
BuildRequires:  scdoc >= 1.9.7
BuildRequires:  util-linux
BuildRequires:  pkgconfig(gbm) >= 21.3
BuildRequires:  pkgconfig(hyprland-protocols)
BuildRequires:  pkgconfig(hyprlang)
BuildRequires:  pkgconfig(inih)
BuildRequires:  pkgconfig(libdrm) >= 2.4.109
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  pkgconfig(pango)
BuildRequires:  pkgconfig(pangocairo)
BuildRequires:  pkgconfig(sdbus-c++)
BuildRequires:  pkgconfig(systemd)
BuildRequires:  pkgconfig(uuid)
BuildRequires:  pkgconfig(wayland-client)
BuildRequires:  pkgconfig(wayland-protocols) >= 1.24
BuildRequires:  pkgconfig(wlroots) >= 0.17.0

# Screencasting won't work without pipewire, but it's not a hard dependency.
Recommends:     pipewire >= 1.1.18

# Required since the picker uses qt wayland.
# Not a strict requirement as the portal will fallback to slurp
Recommends:     qt6-wayland
Requires:       xdg-desktop-portal

%description
A fork of xdg-desktop-portal backend for wlroots for Hyprland. It supports
other wlroots-based Wayland compositors too with some limitations.

%prep
%autosetup -p1
pushd subprojects
rm -rfv hyprland-protocols sdbus-cpp
popd

%build
%cmake \
	-DCMAKE_C_COMPILER="clang" \
	-DCMAKE_CXX_COMPILER="clang++"
%cmake_build

%install
%cmake_install

%pre
%systemd_user_pre %{name}.service

%post
%systemd_user_post %{name}.service

%preun
%systemd_user_preun %{name}.service

%postun
%systemd_user_postun %{name}.service

%files
%{-,root,root,-}
%license LICENSE
%doc README.md CONTRIBUTING.md
%{_bindir}/hyprland-share-picker
%{_libexecdir}/%{name}
%dir %{_datadir}/xdg-desktop-portal
%dir %{_datadir}/xdg-desktop-portal/portals
%{_datadir}/dbus-1/services/org.freedesktop.impl.portal.desktop.hyprland.service
%{_datadir}/xdg-desktop-portal/portals/hyprland.portal
%{_userunitdir}/%{name}.service

%changelog
* Mon Jul 22 2024 Joshua Smith <smolsheep@opensuse.org>
- Remove fix-compilation-with-pw.patch -- Fixed upstream
- Update to version 1.3.3:
  * core: sanitize environment and paths from user data
  * core: fix compilation with newer pw versions
  * required pipewire version is now >= 1.1.82.
* Wed Jul 10 2024 Soc Virnyl Estela <obs@uncomfyhalomacro.pl>
- Add ./fix-compilation-with-pw.patch
* Wed Jul 10 2024 Soc Virnyl Estela <obs@uncomfyhalomacro.pl>
- Switch from gcc to clang
* Tue Jul  9 2024 Soc Virnyl Estela <obs@uncomfyhalomacro.pl>
- Cleanup specfile. Remove subprojects
* Tue Jul  9 2024 Soc Virnyl Estela <obs@uncomfyhalomacro.pl>
- Remove fix-systemd-service-file-install-path.patch
- Add hyprland-protocols as build dependency
* Tue Jul  9 2024 Soc Virnyl Estela <obs@uncomfyhalomacro.pl>
- Update to version 1.3.2:
  * added screencopy:max_fps config option
  * core: don't critically exit when no HOME env is set
  * core: avoid using uninitialized ptrs
  * screencast: remove frame callbacks on stream state change
  * screencast: fixup timing issues with frame re-scheduling
* Sun Feb 25 2024 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Cleanup specfile
  * remove meson as build requirement.
* Sat Feb 24 2024 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Add fix-systemd-service-file-install-path.patch
* Sat Feb 24 2024 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Cleanup specfile
  * we remove sources for hyprland-protocols and hyprlang. They are now separate packages
* Fri Feb 23 2024 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to version 1.3.1:
  * Add hyprlang as new subproject dependency
  * Screencopy: Fixed restore tokens with multiple relaunches
  * Screencopy: Fixed paused -> resume state handling
- Update specfile:
  * Meson and makefile has been obsoleted by CMake. Only
    exception is for hyprland-protocols.
* Tue Nov 28 2023 malcolmlewis@opensuse.org
- Update to version 1.2.5:
  * Added back screenshot functionality,
    (gh#hyprwm/xdg-desktop-portal-hyprland#127).
  * VRAM leak fixes.
  * Destroy pipewire streams when ScreenCast sessions are closed,
    (gh#hyprwm/xdg-desktop-portal-hyprland#130).
- Changes from version 1.2.4:
  * portal: remove screenshot cap from .portal file.
  * Default meson build type to release,
    (gh#hyprwm/xdg-desktop-portal-hyprland#125).
* Sun Oct 22 2023 Nicolas Lorin <androw95220@gmail.com>
- Update to version 1.2.3:
  * Small update still fixing more edge cases causing a CPU core spike after exit.
* Sun Oct 15 2023 Nicolas Lorin <androw95220@gmail.com>
- Update to version 1.2.2:
  * Unbreak build on FreeBSD
  * Fix build when using clang
  * specify flag for manual installation
  * fixes the picker starting at windows and not monitors
  * performance improvements
  * fix for high CPU usage after exit
  * hotfix to 1.2.0 to fix crashes after a few seconds
  * fix some issues with screensharing on non-linear dmabuf GPUs
  * fix xdph not exiting on terminate
* Mon Sep 25 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Remove 0000-sdbus-c++-cmake-lists.patch
- Remove conflicts with XDG-wlr. XDP 0.18.0 introduces flexible
  configuration of portals.
- Update to version 1.1.0:
  * core: rework event loop for polling and C++-style awaits
  * internal: make frame callbacks log a trace
  * internal: add a notification on missing qt-wayland packages
  * drop unused dependencies
  * fix build system
  * add double escaping
* Sat Sep  9 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Add back cmake. Seems they forgotten share picker on the meson.build
* Sat Sep  9 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Further correct mistake by installing of systemd services properly.
* Sat Sep  9 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Revert using cmake and go back using meson
* Thu Sep  7 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Fix build and install for hyprland protocol and the portal
* Thu Sep  7 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Use sdb-c++ from system instead of subproject through cmake patch:
  0000-sdbus-c++-cmake-lists.patch
* Thu Sep  7 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Add libjpeg, cairo, pango(cairo) as deps
* Thu Sep  7 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Use cmake instead of meson.
* Wed Sep  6 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 1.0.0:
  * added sdbus-c++ as dependency
  * this release is a full rewrite from C to C++
* Thu Aug 17 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 0.5.0:
  * pw: guard output in transform checks
  * toplevelexport: remove _done call from _buffer
  * screencast: correct array size
* Tue May 30 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 0.4.0:
  * screencast: restore window by class
  * some nix stuff
* Mon May 22 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Remove some -devel dependencies because this is a runtime package.
* Sat May 13 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Cleanup dependencies
- Hyprland-protocols now uses tag releases
- Improve specfile
- Update xdg-desktop-portal-hyprland to 0.3.1:
  * pw: send transform to pipewire
  * fix implicit function declaration
  * fix build after commit 7d3da7e
* Sun Apr 23 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Make shorter summary but longer description.
* Sun Apr 23 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Set hyprland-protocols-devel to noarch.
* Sun Apr 23 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Create hyprland-protocols-devel package.
  * Assign files for this package.
- Add qt wayland libraries and packages as recommends as they are really
  used for the picker. Not strictly a requirement since it will fallback
  to slurp.
* Sun Apr 16 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Initial spec for xdg-desktop-portal-hyprland 0.2.1
